@@ -1,7 +1,7 @@
 
 /*!
  * Stylus - Evaluator
- * Copyright(c) 2010 LearnBoost <dev@learnboost.com>
+ * Copyright (c) Automattic <developer.wordpress.com>
  * MIT Licensed
  */
 
@@ -26,7 +26,7 @@ var Visitor = require('./')
  *
  * @api private
  */
-function importFile(node, file, literal, index) {
+function importFile(node, file, literal) {
   var importStack = this.importStack
     , Parser = require('../parser')
     , stat;
@@ -41,6 +41,15 @@ function importFile(node, file, literal, index) {
     }
   }
 
+  // Avoid overflows from importing the same file over again
+  if (~importStack.indexOf(file))
+    throw new Error('import loop has been found');
+
+  var str = fs.readFileSync(file, 'utf8');
+
+  // shortcut for empty files
+  if (!str.trim()) return nodes.null;
+
   // Expose imports
   node.path = file;
   node.dirname = dirname(file);
@@ -49,20 +58,16 @@ function importFile(node, file, literal, index) {
   node.mtime = stat.mtime;
   this.paths.push(node.dirname);
 
-  // Avoid overflows from importing the same file over again
-  if (file === importStack[importStack.length - 1]) return nodes.null;
-
   if (this.options._imports) this.options._imports.push(node.clone());
 
   // Parse the file
   importStack.push(file);
   nodes.filename = file;
 
-  var str = fs.readFileSync(file, 'utf8');
-  if (literal && !this.resolveURL) {
+  if (literal) {
     literal = new nodes.Literal(str.replace(/\r\n?/g, '\n'));
     literal.lineno = literal.column = 1;
-    return literal;
+    if (!this.resolveURL) return literal;
   }
 
   // parse
@@ -72,20 +77,28 @@ function importFile(node, file, literal, index) {
   try {
     block = parser.parse();
   } catch (err) {
-    err.filename = file;
-    err.lineno = parser.lexer.prev.lineno;
-    err.column = parser.lexer.prev.column;
-    err.input = str;
-    throw err;
+    var line = parser.lexer.lineno
+      , column = parser.lexer.column;
+
+    if (literal && this.includeCSS && this.resolveURL) {
+      this.warn('ParseError: ' + file + ':' + line + ':' + column + '. This file included as-is');
+      return literal;
+    } else {
+      err.filename = file;
+      err.lineno = line;
+      err.column = column;
+      err.input = str;
+      throw err;
+    }
   }
 
   // Evaluate imported "root"
-  block = block.clone(this.root);
-  block.parent = this.root;
+  block = block.clone(this.currentBlock);
+  block.parent = this.currentBlock;
   block.scope = false;
   var ret = this.visit(block);
   importStack.pop();
-  if (importStack.length || index) this.paths.pop();
+  if (!this.resolveURL || this.resolveURL.nocheck) this.paths.pop();
 
   return ret;
 }
@@ -106,15 +119,17 @@ function importFile(node, file, literal, index) {
 var Evaluator = module.exports = function Evaluator(root, options) {
   options = options || {};
   Visitor.call(this, root);
+  var functions = this.functions = options.functions || {};
   this.stack = new Stack;
   this.imports = options.imports || [];
-  this.functions = options.functions || {};
   this.globals = options.globals || {};
   this.paths = options.paths || [];
   this.prefix = options.prefix || '';
   this.filename = options.filename;
   this.includeCSS = options['include css'];
-  this.resolveURL = options['resolve url'];
+  this.resolveURL = functions.url
+    && 'resolver' == functions.url.name
+    && functions.url.options;
   this.paths.push(dirname(options.filename || '.'));
   this.stack.push(this.global = new Frame(root));
   this.warnings = options.warn;
@@ -195,16 +210,27 @@ Evaluator.prototype.populateGlobalScope = function(){
 
   // colors
   Object.keys(colors).forEach(function(name){
-    var rgb = colors[name]
-      , rgba = new nodes.RGBA(rgb[0], rgb[1], rgb[2], 1)
+    var color = colors[name]
+      , rgba = new nodes.RGBA(color[0], color[1], color[2], color[3])
       , node = new nodes.Ident(name, rgba);
+    rgba.name = name;
     scope.add(node);
   });
 
+  // expose url function
+  scope.add(new nodes.Ident(
+    'embedurl',
+    new nodes.Function('embedurl', require('../functions/url')({
+      limit: false
+    }))
+  ));
+
   // user-defined globals
   var globals = this.globals;
   Object.keys(globals).forEach(function(name){
-    scope.add(new nodes.Ident(name, globals[name]));
+    var val = globals[name];
+    if (!val.nodeName) val = new nodes.Literal(val);
+    scope.add(new nodes.Ident(name, val));
   });
 };
 
@@ -260,7 +286,19 @@ Evaluator.prototype.visitMedia = function(media){
  */
 
 Evaluator.prototype.visitQueryList = function(queries){
+  var val, query;
   queries.nodes.forEach(this.visit, this);
+
+  if (1 == queries.nodes.length) {
+    query = queries.nodes[0];
+    if (val = this.lookup(query.type)) {
+      val = val.first.string;
+      if (!val) return queries;
+      var Parser = require('../parser')
+        , parser = new Parser(val, this.options);
+      queries = this.visit(parser.queries());
+    }
+  }
   return queries;
 };
 
@@ -269,22 +307,17 @@ Evaluator.prototype.visitQueryList = function(queries){
  */
 
 Evaluator.prototype.visitQuery = function(node){
-  var val;
   node.predicate = this.visit(node.predicate);
   node.type = this.visit(node.type);
-  if (val = this.lookup(node.type)) {
-    node.type = val.first.string || val.first.name;
-  }
   node.nodes.forEach(this.visit, this);
   return node;
 };
 
 /**
- * Visit QueryExpr.
+ * Visit Feature.
  */
 
-Evaluator.prototype.visitQueryExpr = function(node){
-  var val;
+Evaluator.prototype.visitFeature = function(node){
   node.name = this.interpolate(node);
   if (node.expr) {
     this.return++;
@@ -332,7 +365,7 @@ Evaluator.prototype.visitMember = function(node){
 Evaluator.prototype.visitKeyframes = function(keyframes){
   var val;
   if (keyframes.fabricated) return keyframes;
-  keyframes.val = this.interpolate(keyframes);
+  keyframes.val = this.interpolate(keyframes).trim();
   if (val = this.lookup(keyframes.val)) {
     keyframes.val = val.first.string || val.first.name;
   }
@@ -718,10 +751,31 @@ Evaluator.prototype.visitAtblock = function(atblock){
 
 Evaluator.prototype.visitAtrule = function(atrule){
   atrule.val = this.interpolate(atrule);
-  atrule.block = this.visit(atrule.block);
+  if (atrule.block) atrule.block = this.visit(atrule.block);
   return atrule;
 };
 
+/**
+ * Visit Supports.
+ */
+
+Evaluator.prototype.visitSupports = function(node){
+  var condition = node.condition
+    , val;
+
+  this.return++;
+  node.condition = this.visit(condition);
+  this.return--;
+
+  val = condition.first;
+  if (1 == condition.nodes.length
+    && 'string' == val.nodeName) {
+    node.condition = val.string;
+  }
+  node.block = this.visit(node.block);
+  return node;
+};
+
 /**
  * Visit If.
  */
@@ -773,9 +827,13 @@ Evaluator.prototype.visitIf = function(node){
   }
 
   // mixin conditional statements within
-  // a selector group, @font-face block or @page block
+  // a selector group or at-rule
   if (ret && !node.postfix && block.node
-    && ~['group', 'atrule'].indexOf(block.node.nodeName)) {
+    && ~['group'
+       , 'atrule'
+       , 'media'
+       , 'supports'
+       , 'keyframes'].indexOf(block.node.nodeName)) {
     this.mixin(ret.nodes, block);
     return nodes.null;
   }
@@ -795,6 +853,7 @@ Evaluator.prototype.visitExtend = function(extend){
       // Cloning the selector for when we are in a loop and don't want it to affect
       // the selector nodes and cause the values to be different to expected
       selector: this.interpolate(selector.clone()).trim(),
+      optional: selector.optional,
       lineno: selector.lineno,
       column: selector.column
     });
@@ -812,8 +871,7 @@ Evaluator.prototype.visitImport = function(imported){
   var path = this.visit(imported.path).first
     , nodeName = imported.once ? 'require' : 'import'
     , found
-    , literal
-    , index;
+    , literal;
 
   this.return--;
   debug('import %s', path);
@@ -830,8 +888,8 @@ Evaluator.prototype.visitImport = function(imported){
 
   var name = path = path.string;
 
-  // Absolute URL
-  if (/url\s*\(\s*['"]?(?:https?:)?\/\//i.test(path)) {
+  // Absolute URL or hash
+  if (/(?:url\s*\(\s*)?['"]?(?:#|(?:https?:)?\/\/)/i.test(path)) {
     if (imported.once) throw new Error('You cannot @require a url');
     return imported;
   }
@@ -851,7 +909,6 @@ Evaluator.prototype.visitImport = function(imported){
   found = utils.find(path, this.paths, this.filename);
   if (!found) {
     found = utils.lookupIndex(name, this.paths, this.filename);
-    index = true;
   }
 
   // Throw if import failed
@@ -860,7 +917,7 @@ Evaluator.prototype.visitImport = function(imported){
   var block = new nodes.Block;
 
   for (var i = 0, len = found.length; i < len; ++i) {
-    block.push(importFile.call(this, imported, found[i], literal, index));
+    block.push(importFile.call(this, imported, found[i], literal));
   }
 
   return block;
@@ -934,7 +991,7 @@ Evaluator.prototype.invokeFunction = function(fn, args, content){
       var arg = args.map[node.name] || args.nodes[i++];
       node = node.clone();
       if (arg) {
-        arg.isEmpty ? args.nodes[i - 1] = node.val : node.val = arg;
+        arg.isEmpty ? args.nodes[i - 1] = this.visit(node) : node.val = arg;
       } else {
         args.push(node.val);
       }
@@ -946,7 +1003,7 @@ Evaluator.prototype.invokeFunction = function(fn, args, content){
     }
 
     scope.add(node);
-  });
+  }, this);
 
   // mixin block
   if (content) scope.add(new nodes.Ident('block', content, true));
@@ -973,7 +1030,10 @@ Evaluator.prototype.invokeBuiltin = function(fn, args){
   if (fn.raw) {
     args = args.nodes;
   } else {
-    args = utils.params(fn).reduce(function(ret, param){
+    if (!fn.params) {
+      fn.params = utils.params(fn);
+    }
+    args = fn.params.reduce(function(ret, param){
       var arg = args.map[param] || args.nodes.shift()
       if (arg) {
         arg = utils.unwrap(arg);
@@ -1048,7 +1108,8 @@ Evaluator.prototype.mixin = function(nodes, block){
   var len = block.nodes.length
     , head = block.nodes.slice(0, block.index)
     , tail = block.nodes.slice(block.index + 1, len);
-  this._mixin(nodes, head);
+  this._mixin(nodes, head, block);
+  block.index = 0;
   block.nodes = head.concat(tail);
 };
 
@@ -1057,10 +1118,11 @@ Evaluator.prototype.mixin = function(nodes, block){
  *
  * @param {Array} items
  * @param {Array} dest
+ * @param {Block} block
  * @api private
  */
 
-Evaluator.prototype._mixin = function(items, dest){
+Evaluator.prototype._mixin = function(items, dest, block){
   var node
     , len = items.length;
   for (var i = 0; i < len; ++i) {
@@ -1068,8 +1130,14 @@ Evaluator.prototype._mixin = function(items, dest){
       case 'return':
         return;
       case 'block':
-        this._mixin(node.nodes, dest);
+        this._mixin(node.nodes, dest, block);
         break;
+      case 'media':
+        // fix link to the parent block
+        var parentNode = node.block.parent.node;
+        if (parentNode && 'call' != parentNode.nodeName) {
+          node.block.parent = block;
+        }
       case 'property':
         var val = node.expr;
         // prevent `block` mixin recursion
@@ -1078,7 +1146,6 @@ Evaluator.prototype._mixin = function(items, dest){
           val.nodes[0] = new nodes.Literal('block');
         }
       default:
-        if (0 == i) node = this.visit(node);
         dest.push(node);
     }
   }
@@ -1122,8 +1189,8 @@ Evaluator.prototype.mixinObject = function(object){
     block = parser.parse();
   } catch (err) {
     err.filename = this.filename;
-    err.lineno = parser.lexer.prev.lineno;
-    err.column = parser.lexer.prev.column;
+    err.lineno = parser.lexer.lineno;
+    err.column = parser.lexer.column;
     err.input = str;
     throw err;
   }
@@ -1269,6 +1336,7 @@ Evaluator.prototype.__defineGetter__('closestBlock', function(){
         case 'atrule':
         case 'atblock':
         case 'media':
+        case 'call':
           return block;
       }
     }
@@ -1353,7 +1421,7 @@ Evaluator.prototype.interpolate = function(node){
       case 'literal':
       case 'string':
         if (self.prefix && !node.prefixed && !node.val.nodeName) {
-          node.val = node.val.replace(/\./g, '.' + self.prefix);
+          node.val = node.val.replace(/\.(?=[\w-])|^\.$/g, '.' + self.prefix);
           node.prefixed = true;
         }
         return node.val;
@@ -1477,7 +1545,7 @@ Evaluator.prototype.castable = function(expr){
 
 Evaluator.prototype.warn = function(msg){
   if (!this.warnings) return;
-  console.warn('\033[33mWarning:\033[0m ' + msg);
+  console.warn('\u001b[33mWarning:\u001b[0m ' + msg);
 };
 
 /**
